<?php
if ( ! class_exists( 'ReduxFrameworkInstances' ) ) {
	return;
}

class CSS_Generator {
	/**
     * scssc class instance
     *
     * @access protected
     * @var scssc
     */
    protected $scssc = null;

    /**
     * ReduxFramework class instance
     *
     * @access protected
     * @var ReduxFramework
     */
    protected $redux = null;

    /**
     * Debug mode is turn on or not
     *
     * @access protected
     * @var boolean
     */
    protected $dev_mode = true;

    /**
     * opt_name of ReduxFramework
     *
     * @access protected
     * @var string
     */
    protected $opt_name = '';

	/**
	 * Constructor
	 */
	function __construct() {
		$this->opt_name = amarou_get_opt_name();

		if ( empty( $this->opt_name ) ) {
			return;
		}
		$this->dev_mode = amarou_get_opt( 'dev_mode', '0' ) === '1' ? true : false;
		add_filter( 'cms_scssc_on', '__return_true' );
		add_action( 'init', array( $this, 'init' ) );
		add_action( 'wp_enqueue_scripts', array( $this, 'enqueue' ), 20 );
	}

	/**
	 * init hook - 10
	 */
	function init() {
		if ( ! class_exists( 'scssc' ) ) {
			return;
		}

		$this->redux = ReduxFrameworkInstances::get_instance( $this->opt_name );

		if ( empty( $this->redux ) || ! $this->redux instanceof ReduxFramework ) {
			return;
		}
		add_action( 'wp', array( $this, 'generate_with_dev_mode' ) );
		add_action( "redux/options/{$this->opt_name}/saved", function () {
			$this->generate_file();
		} );
	}

	function generate_with_dev_mode() {
		if ( $this->dev_mode === true ) {
			$this->generate_file();
		}
	}

	/**
	 * Generate options and css files
	 */
	function generate_file() {
		$scss_dir = get_template_directory() . '/assets/scss/';
		$css_dir  = get_template_directory() . '/assets/css/';

		$this->scssc = new scssc();
		$this->scssc->setImportPaths( $scss_dir );

		$_options = $scss_dir . 'variables.scss';

		$this->redux->filesystem->execute( 'put_contents', $_options, array(
			'content' => preg_replace( "/(?<=[^\r]|^)\n/", "\r\n", $this->options_output() )
		) );
		$css_file = $css_dir . 'theme.css';

		$this->scssc->setFormatter( 'scss_formatter' );
		$this->redux->filesystem->execute( 'put_contents', $css_file, array(
			'content' => preg_replace( "/(?<=[^\r]|^)\n/", "\r\n", $this->scssc->compile( '@import "theme.scss"' ) )
		) );
	}

	/**
	 * Output options to _variables.scss
	 *
	 * @access protected
	 * @return string
	 */
	protected function options_output() {
		ob_start();

		$primary_color = amarou_get_opt( 'primary_color', '#ff4c01' );
		if ( ! amarou_is_valid_color( $primary_color ) ) {
			$primary_color = '#ff4c01';
		}
		printf( '$primary_color: %s;', esc_attr( $primary_color ) );

		$secondary_color = amarou_get_opt( 'secondary_color', '#1b1a1a' );
		if ( ! amarou_is_valid_color( $secondary_color ) ) {
			$secondary_color = '#1b1a1a';
		}
		printf( '$secondary_color: %s;', esc_attr( $secondary_color ) );

		$link_color = amarou_get_opt( 'link_color', '#ff4c01' );
		if ( ! empty( $link_color['regular'] ) && isset( $link_color['regular'] ) ) {
			printf( '$link_color: %s;', esc_attr( $link_color['regular'] ) );
		} else {
			echo '$link_color: #ff4c01;';
		}

		$link_color_hover = amarou_get_opt( 'link_color', '#ff4c01' );
		if ( ! empty( $link_color['hover'] ) && isset( $link_color['hover'] ) ) {
			printf( '$link_color_hover: %s;', esc_attr( $link_color['hover'] ) );
		} else {
			echo '$link_color_hover: #ff4c01;';
		}

		$link_color_active = amarou_get_opt( 'link_color', '#ff4c01' );
		if ( ! empty( $link_color['active'] ) && isset( $link_color['active'] ) ) {
			printf( '$link_color_active: %s;', esc_attr( $link_color['active'] ) );
		} else {
			echo '$link_color_active: #ff4c01;';
		}

		/* Font */
		$body_default_font = amarou_get_opt( 'body_default_font', 'Roboto' );
		if ( isset( $body_default_font ) ) {
			echo '
                $body_default_font: ' . esc_attr( $body_default_font ) . ';
            ';
		}

		$heading_default_font = amarou_get_opt( 'heading_default_font', 'Barlow' );
		if ( isset( $heading_default_font ) ) {
			echo '
                $heading_default_font: ' . esc_attr( $heading_default_font ) . ';
            ';
		}

		return ob_get_clean();
	}

	/**
	 * Hooked wp_enqueue_scripts - 20
	 * Make sure that the handle is enqueued from earlier wp_enqueue_scripts hook.
	 */
	function enqueue() {
		$css = $this->inline_css();
		if ( ! empty( $css ) ) {
			wp_add_inline_style( 'amarou-theme', $this->dev_mode ? $css : amarou_css_minifier( $css ) );
		}
	}

	/**
	 * Generate inline css based on theme options
	 */
	protected function inline_css() {
		ob_start();
		/* Logo */
		$logo_maxh = amarou_get_opt( 'logo_maxh' );

		if ( ! empty( $logo_maxh['height'] ) && $logo_maxh['height'] != 'px' ) {
			printf( '#site-header-wrap .site-branding a img { max-height: %s !important; }', esc_attr( $logo_maxh['height'] ) );
		} ?>
		<?php $logo_maxh_sm = amarou_get_opt( 'logo_maxh_sm' );
		if ( ! empty( $logo_maxh_sm['height'] ) && $logo_maxh_sm['height'] != 'px' ) {
			printf( '@media screen and (max-width: 991px) { #site-header-wrap .site-branding a img { max-height: %s  !important; } }', esc_attr( $logo_maxh_sm['height'] ) );
		} ?>
		<?php /* Menu */
		$menu_text_transform = amarou_get_opt( 'menu_text_transform' );
		if ( ! empty( $menu_text_transform ) ) {
			printf( '.primary-menu > li > a { text-transform: %s !important; }', esc_attr( $menu_text_transform ) );
		}
		$menu_font_size = amarou_get_opt( 'menu_font_size' );
		if ( ! empty( $menu_font_size ) ) {
			printf( '.primary-menu > li > a { font-size: %s' . 'px !important; }', esc_attr( $menu_font_size ) );
		}
		$main_menu_color = amarou_get_opt( 'main_menu_color' );
		if ( ! empty( $main_menu_color['regular'] ) ) {
			printf( '.primary-menu > li > a { color: %s !important; }', esc_attr( $main_menu_color['regular'] ) );
		}
		if ( ! empty( $main_menu_color['hover'] ) ) {
			printf( '.primary-menu > li > a:hover { color: %s !important; }', esc_attr( $main_menu_color['hover'] ) );
		}
		if ( ! empty( $main_menu_color['active'] ) ) {
			printf( '.primary-menu > li.current_page_item > a, .primary-menu > li.current-menu-item > a, .primary-menu > li.current_page_ancestor > a, .primary-menu > li.current-menu-ancestor > a { color: %s !important; }', esc_attr( $main_menu_color['active'] ) );
		}
		$sticky_menu_color = amarou_get_opt( 'sticky_menu_color' );
		if ( ! empty( $sticky_menu_color['regular'] ) ) {
			printf( '#site-header.h-fixed .primary-menu > li > a { color: %s !important; }', esc_attr( $sticky_menu_color['regular'] ) );
		}
		if ( ! empty( $sticky_menu_color['hover'] ) ) {
			printf( '#site-header.h-fixed .primary-menu > li > a:hover { color: %s !important; }', esc_attr( $sticky_menu_color['hover'] ) );
		}
		if ( ! empty( $sticky_menu_color['active'] ) ) {
			printf( '#site-header.h-fixed .primary-menu > li.current_page_item > a, #site-header.h-fixed .primary-menu > li.current-menu-item > a, #site-header.h-fixed .primary-menu > li.current_page_ancestor > a, #site-header.h-fixed .primary-menu > li.current-menu-ancestor > a { color: %s !important; }', esc_attr( $sticky_menu_color['active'] ) );
		}

		/* Page Title */


		$shop_page_title_img = amarou_get_opt( 'shop_page_title_img' );
		if ( ! empty( $shop_page_title_img['url'] ) ) {
			echo '.post-type-archive-product #pagetitle.page-title {
                background-image: url(' . esc_attr( $shop_page_title_img['url'] ) . ') !important;
            }';
		}

		$custom_pagetitle = amarou_get_page_opt( 'custom_pagetitle' );
		$ptitle_bg = amarou_get_page_opt( 'page_title_bg' );
		if ( $custom_pagetitle == 'show' && ! empty( $ptitle_bg['url'] ) ) {
			echo 'body #pagetitle.page-title {
                background-image: url(' . esc_attr( $ptitle_bg['url'] ) . ') !important;
            }';
		}

		/* Content */
		$content_bg_color = amarou_get_page_opt( 'content_bg_color' );
		if ( ! empty( $content_bg_color['color'] ) ) {
			echo '#pagetitle svg path {
                fill: ' . esc_attr( $content_bg_color['color'] ) . ';
            }';
		}

		/* Preset */
		$p_primary_color = amarou_get_page_opt( 'p_primary_color' );
		if ( ! empty( $p_primary_color ) ) {
			echo '.cms-navigation-menu1.style1 li a:before, 
			.cms-newsletter1.style1 .tnp-field-button:before,
			.cms-newsletter1.style2 .tnp-field-button:before,
			#cms-loadding .loading-spinner,
			.link-primary-color a, .link-primary-color a:hover,
			#site-header-wrap .site-header-right .site-header-social a:hover,
			#site-header-wrap .site-header-right .site-header-item:hover,
			.btn.btn-outline,
			.primary-menu > li:hover > a, .primary-menu > li.current_page_item > a, .primary-menu > li.current-menu-item > a, .primary-menu > li.current_page_ancestor > a, .primary-menu > li.current-menu-ancestor > a,
			.primary-menu .sub-menu li > a:hover, .primary-menu .sub-menu li.current_page_item > a, .primary-menu .sub-menu li.current-menu-item > a, .primary-menu .sub-menu li.current_page_ancestor > a, .primary-menu .sub-menu li.current-menu-ancestor > a,
			.cms-widget-cart-sidebar .widget_shopping_cart .widget_shopping_cart_content ul.cart_list a.remove_from_cart_button,
			.btn.btn-video-white:not(:hover),
			.cms-fancy-box-layout1 .item--icon i,
			.grid-filter-wrap span.active, .grid-filter-wrap span:hover,
			.cms-pricing-layout1 .cms-pricing-feature i,
			.cms-slick-carousel .slick-arrow:hover, .cms-slick-nav .slick-arrow:hover,
			.cms-fancy-box-layout1 .item--button a, 
			#site-header-wrap .header-top-layout2 .header-top-item label,
			#site-header-wrap .header-top-layout2 .header-top-meta .header-top-social a:hover,
			.cms-fancy-box-layout1.style4:hover .item--title,
			.cms-heading-wrapper .custom-subheading,
			.cms-team .item--position,
			.cms-post-carousel-layout1 .item-title a:hover,
			.btn-text:hover, .cms-team .item--social a:hover,
			.heading-mail a:hover, .cms-social a:not(:hover),
			.cms-hidden-sidebar .cms-hidden-close:hover,
			.cms-testimonial-carousel3 .cms-slick-primary .testimonial-wg-title,
			.cms-fancy-box-layout3 .item--button a, 
			.cms-product-grid-layout1 .item-price,
			.cms-grid .item-title a:hover,
			.cms-banner-box-layout2 .cms-banner-box-holder .btn,
			.cms-banner-box-layout2 .cms-banner-box-meta .item--title,
			.cms-banner-box-layout3 .cms-banner-box-holder .item--price,
			.cms-header-popup-wrap .cms-header-meta .item--social a,
			.cms-header-popup-wrap .cms-main-menu-popup a:hover,
			.cms-portfolio-grid1 .item-category a:hover,
			.cms-modal-search .search-submit {
                color: ' . esc_attr( $p_primary_color ) . ';
            }';

            echo '.cms-newsletter1.style1 .tnp-email:focus,
            .cms-newsletter1.style2 .tnp-email:focus,
            .btn.btn-outline,
            .cms-testimonial-carousel1 .cms-slick-nav .slick-current .testimonial-image::before, 
            .cms-testimonial-carousel2 .cms-slick-nav .slick-current .testimonial-image::before, 
            .cms-testimonial-carousel3 .cms-slick-nav .slick-current .testimonial-image::before,
            .cms-contact-form-layout1.style1 .wpcf7-form-control:not(.wpcf7-submit):focus, .btn-text:hover,
            .cms-video-player.style2 .cms-video-bg-image + .btn-video .line-video-animation,
            .cms-newsletter2 .tnp-email:focus {
                border-color: ' . esc_attr( $p_primary_color ) . ';
            }';

            echo '.primary-menu > li > a::before,
            #site-header-wrap .site-header-right .site-header-cart .widget_cart_counter_header,
            .btn.btn-outline::before,
            .primary-menu .sub-menu li a::before,
            .main-menu-toggle,
            .cms-widget-cart-sidebar .widget_shopping_cart .widget_shopping_cart_footer p.buttons .btn:not(:hover),
            .cms-contact-form-layout1.style2 .wpcf7-submit:not(:hover),
            .cms-banner-box-layout1 .cms-banner-box-content-inner,
            .btn.btn-default, .btn.btn-default:hover, .wpcf7-submit.btn:not(:hover), 
            .scroll-top, .btn.btn-white::before, .scroll-top:hover, .scroll-top:focus, .scroll-top:active,
            .cms-slick-carousel .slick-arrow:hover::before, .cms-slick-nav .slick-arrow:hover::before,
            .cms-progress-wrapper .elementor-progress-bar,
            .cms-post-grid-layout1 .item-featured .item-category, .cms-post-carousel-layout1 .item-featured .item-category,
            .cms-post-grid-layout1 .item-title::before, .cms-post-carousel-layout1 .item-title::before,
            .btn.btn-secondary::before, .cms-widget-cart-sidebar .cms-close:hover,
            #site-header-wrap.header-layout1 #site-header:not(.h-fixed) .site-header-button .btn::before,
            #site-header-wrap.header-layout5 #site-header:not(.h-fixed) .site-header-button .btn::before,
            .cms-video-player.style2 .cms-video-bg-image + .btn-video,
            #site-header-wrap.header-layout5 #site-header:not(.h-fixed) .site-header-right .site-header-button .btn::before,
            .pricing-box .cms-pricing-layout1 .cms-pricing-inner .pricing-button .btn:not(:hover), .cms-contact-wrap,
            .cms-widget-cart-sidebar .widget_shopping_cart .widget_shopping_cart_content ul.cart_list li.empty .btn:not(:hover),
            #site-header-wrap.header-layout6 #site-header:not(.h-fixed) .site-header-button .btn::before {
                background-color: ' . esc_attr( $p_primary_color ) . ';
            }';
            
            echo '.cms-testimonial-carousel1 .cms-slick-primary svg, .cms-testimonial-carousel2 .cms-slick-primary svg, .cms-testimonial-carousel3 .cms-slick-primary svg {
                fill: ' . esc_attr( $p_primary_color ) . ';
            }';
		}
		/* End Preset */

		/* Custom Css */
		$custom_css = amarou_get_opt( 'site_css' );
		if ( ! empty( $custom_css ) ) {
			echo esc_attr( $custom_css );
		}

		return ob_get_clean();
	}
}

new CSS_Generator();