<?php
/**
 * Register metabox for posts based on Redux Framework. Supported methods:
 *     isset_args( $post_type )
 *     set_args( $post_type, $redux_args, $metabox_args )
 *     add_section( $post_type, $sections )
 * Each post type can contains only one metabox. Pease note that each field id
 * leads by an underscore sign ( _ ) in order to not show that into Custom Field
 * Metabox from WordPress core feature.
 *
 * @param  CMS_Post_Metabox $metabox
 */

add_action( 'cms_post_metabox_register', 'amarou_page_options_register' );

function amarou_page_options_register( $metabox ) {

	if ( ! $metabox->isset_args( 'post' ) ) {
		$metabox->set_args( 'post', array(
			'opt_name'            => 'post_option',
			'display_name'        => esc_html__( 'Post Settings', 'amarou' ),
			'show_options_object' => false,
		), array(
			'context'  => 'advanced',
			'priority' => 'default'
		) );
	}

	if ( ! $metabox->isset_args( 'product' ) ) {
		$metabox->set_args( 'product', array(
			'opt_name'            => 'product_option',
			'display_name'        => esc_html__( 'Product Settings', 'amarou' ),
			'show_options_object' => false,
		), array(
			'context'  => 'advanced',
			'priority' => 'default'
		) );
	}

	if ( ! $metabox->isset_args( 'page' ) ) {
		$metabox->set_args( 'page', array(
			'opt_name'            => amarou_get_page_opt_name(),
			'display_name'        => esc_html__( 'Page Settings', 'amarou' ),
			'show_options_object' => false,
		), array(
			'context'  => 'advanced',
			'priority' => 'default'
		) );
	}

	if ( ! $metabox->isset_args( 'cms_pf_audio' ) ) {
		$metabox->set_args( 'cms_pf_audio', array(
			'opt_name'     => 'post_format_audio',
			'display_name' => esc_html__( 'Audio', 'amarou' ),
			'class'        => 'fully-expanded',
		), array(
			'context'  => 'advanced',
			'priority' => 'default'
		) );
	}

	if ( ! $metabox->isset_args( 'cms_pf_link' ) ) {
		$metabox->set_args( 'cms_pf_link', array(
			'opt_name'     => 'post_format_link',
			'display_name' => esc_html__( 'Link', 'amarou' )
		), array(
			'context'  => 'advanced',
			'priority' => 'default'
		) );
	}

	if ( ! $metabox->isset_args( 'cms_pf_quote' ) ) {
		$metabox->set_args( 'cms_pf_quote', array(
			'opt_name'     => 'post_format_quote',
			'display_name' => esc_html__( 'Quote', 'amarou' )
		), array(
			'context'  => 'advanced',
			'priority' => 'default'
		) );
	}

	if ( ! $metabox->isset_args( 'cms_pf_video' ) ) {
		$metabox->set_args( 'cms_pf_video', array(
			'opt_name'     => 'post_format_video',
			'display_name' => esc_html__( 'Video', 'amarou' ),
			'class'        => 'fully-expanded',
		), array(
			'context'  => 'advanced',
			'priority' => 'default'
		) );
	}

	if ( ! $metabox->isset_args( 'cms_pf_gallery' ) ) {
		$metabox->set_args( 'cms_pf_gallery', array(
			'opt_name'     => 'post_format_gallery',
			'display_name' => esc_html__( 'Gallery', 'amarou' ),
			'class'        => 'fully-expanded',
		), array(
			'context'  => 'advanced',
			'priority' => 'default'
		) );
	}

	/* Extra Post Type */

	if ( ! $metabox->isset_args( 'portfolio' ) ) {
		$metabox->set_args( 'portfolio', array(
			'opt_name'            => 'portfolio_option',
			'display_name'        => esc_html__( 'Portfolio Settings', 'amarou' ),
			'show_options_object' => false,
		), array(
			'context'  => 'advanced',
			'priority' => 'default'
		) );
	}

	if ( ! $metabox->isset_args( 'service' ) ) {
		$metabox->set_args( 'service', array(
			'opt_name'            => 'service_option',
			'display_name'        => esc_html__( 'Service Settings', 'amarou' ),
			'show_options_object' => false,
		), array(
			'context'  => 'advanced',
			'priority' => 'default'
		) );
	}

	/**
	 * Config post meta options
	 *
	 */
	$metabox->add_section( 'post', array(
		'title'  => esc_html__( 'Post Settings', 'amarou' ),
		'icon'   => 'el el-refresh',
		'fields' => array(
			array(
				'id'             => 'post_content_padding',
				'type'           => 'spacing',
				'output'         => array( '.single-post #content' ),
				'right'          => false,
				'left'           => false,
				'mode'           => 'padding',
				'units'          => array( 'px' ),
				'units_extended' => 'false',
				'title'          => esc_html__( 'Content Padding', 'amarou' ),
				'subtitle'     => esc_html__( 'Content site paddings.', 'amarou' ),
				'desc'           => esc_html__( 'Default: Theme Option.', 'amarou' ),
				'default'        => array(
					'padding-top'    => '',
					'padding-bottom' => '',
					'units'          => 'px',
				)
			),
			array(
				'id'      => 'show_sidebar_post',
				'type'    => 'switch',
				'title'   => esc_html__( 'Custom Sidebar', 'amarou' ),
				'default' => false,
				'indent'  => true
			),
			array(
				'id'           => 'sidebar_post_pos',
				'type'         => 'button_set',
				'title'        => esc_html__( 'Sidebar Position', 'amarou' ),
				'options'      => array(
					'left'  => esc_html__('Left', 'amarou'),
	                'right' => esc_html__('Right', 'amarou'),
	                'none'  => esc_html__('Disabled', 'amarou')
				),
				'default'      => 'right',
				'required'     => array( 0 => 'show_sidebar_post', 1 => '=', 2 => '1' ),
				'force_output' => true
			),
		)
	) );

	/**
	 * Config page meta options
	 *
	 */
	$metabox->add_section( 'page', array(
		'title'  => esc_html__( 'Header', 'amarou' ),
		'desc'   => esc_html__( 'Header settings for the page.', 'amarou' ),
		'icon'   => 'el-icon-website',
		'fields' => array(
			array(
				'id'      => 'custom_header',
				'type'    => 'switch',
				'title'   => esc_html__( 'Custom Header', 'amarou' ),
				'default' => false,
				'indent'  => true
			),
			array(
				'id'           => 'header_layout',
				'type'         => 'image_select',
				'title'        => esc_html__( 'Layout', 'amarou' ),
				'subtitle'     => esc_html__( 'Select a layout for header.', 'amarou' ),
				'options'      => array(
					'0' => get_template_directory_uri() . '/assets/images/header-layout/h0.jpg',
					'1' => get_template_directory_uri() . '/assets/images/header-layout/h1.jpg',
					'2' => get_template_directory_uri() . '/assets/images/header-layout/h2.jpg',
					'3' => get_template_directory_uri() . '/assets/images/header-layout/h3.jpg',
				),
				'default'      => amarou_get_option_of_theme_options( 'header_layout' ),
				'required'     => array( 0 => 'custom_header', 1 => 'equals', 2 => '1' ),
				'force_output' => true
			),
			array(
	            'id'       => 'p_logo_dark',
	            'type'     => 'media',
	            'title'    => esc_html__('Custom Logo Dark', 'amarou'),
	            'required'     => array( 0 => 'custom_header', 1 => 'equals', 2 => '1' ),
				'force_output' => true
	        ),
	        array(
	            'id'       => 'p_logo_light',
	            'type'     => 'media',
	            'title'    => esc_html__('Custom Logo Light', 'amarou'),
	            'required'     => array( 0 => 'custom_header', 1 => 'equals', 2 => '1' ),
				'force_output' => true
	        ),
	        array(
	            'id' => 'h_btn_text_custom',
	            'type' => 'text',
	            'title' => esc_html__('Navigation Button Text', 'amarou'),
	            'default' => '',
	            'required' => array( 0 => 'custom_header', 1 => 'equals', 2 => '1' ),
	            'force_output' => true
	        ),
		)
	) );

	$metabox->add_section( 'page', array(
		'title'  => esc_html__( 'Page Title', 'amarou' ),
		'icon'   => 'el el-indent-left',
		'fields' => array(
			array(
				'id'           => 'custom_pagetitle',
				'type'         => 'button_set',
				'title'        => esc_html__( 'Page Title', 'amarou' ),
				'options'      => array(
					'themeoption'  => esc_html__( 'Theme Option', 'amarou' ),
					'show'  => esc_html__( 'Custom', 'amarou' ),
					'hide'  => esc_html__( 'Hide', 'amarou' ),
				),
				'default'      => 'themeoption',
			),

			array(
				'id'           => 'custom_title',
				'type'         => 'textarea',
				'title'        => esc_html__( 'Title', 'amarou' ),
				'subtitle'     => esc_html__( 'Use custom title for this page. The default title will be used on document title.', 'amarou' ),
				'required'     => array( 0 => 'custom_pagetitle', 1 => '=', 2 => 'show' ),
				'force_output' => true
			),

			array(
	            'id'       => 'page_title_bg',
	            'type'     => 'media',
	            'title'    => esc_html__('Page Title Image', 'amarou'),
	            'required' => array( 0 => 'custom_pagetitle', 1 => 'equals', 2 => 'show' ),
	            'force_output' => true
	        ),

	        array(
				'id'             => 'page_title_padding',
				'type'           => 'spacing',
				'output'         => array( 'body #pagetitle.page-title' ),
				'right'          => false,
				'left'           => false,
				'mode'           => 'padding',
				'units'          => array( 'px' ),
				'units_extended' => 'false',
				'title'          => esc_html__( 'Content Padding', 'amarou' ),
				'desc'           => esc_html__( 'Default: Theme Option.', 'amarou' ),
				'default'        => array(
					'padding-top'    => '',
					'padding-bottom' => '',
					'units'          => 'px',
				),
				'required' => array( 0 => 'custom_pagetitle', 1 => 'equals', 2 => 'show' ),
	            'force_output' => true
			),
			array(
	            'id'           => 'page_breadcrumb',
	            'type'         => 'button_set',
	            'title'        => esc_html__( 'Breadcrumbs', 'amarou' ),
	            'options'      => array(
	                'themeoption'  => esc_html__( 'Theme Option', 'amarou' ),
	                'show'  => esc_html__( 'Show', 'amarou' ),
	                'hide'  => esc_html__( 'Hide', 'amarou' ),
	            ),
	            'default'      => 'themeoption',
	            'required' => array( 0 => 'custom_pagetitle', 1 => 'equals', 2 => 'show' ),
	            'force_output' => true
	        ),

		)
	) );

	$metabox->add_section( 'page', array(
		'title'  => esc_html__( 'Content', 'amarou' ),
		'desc'   => esc_html__( 'Settings for content area.', 'amarou' ),
		'icon'   => 'el-icon-pencil',
		'fields' => array(
			array(
				'id'       => 'content_bg_color',
				'type'     => 'color_rgba',
				'title'    => esc_html__( 'Background Color', 'amarou' ),
				'subtitle' => esc_html__( 'Content background color.', 'amarou' ),
				'output'   => array( 'background-color' => 'body' )
			),
			array(
				'id'             => 'content_padding',
				'type'           => 'spacing',
				'output'         => array( '#content' ),
				'right'          => false,
				'left'           => false,
				'mode'           => 'padding',
				'units'          => array( 'px' ),
				'units_extended' => 'false',
				'title'          => esc_html__( 'Content Padding', 'amarou' ),
				'desc'           => esc_html__( 'Default: Theme Option.', 'amarou' ),
				'default'        => array(
					'padding-top'    => '',
					'padding-bottom' => '',
					'units'          => 'px',
				)
			),
			array(
				'id'      => 'show_sidebar_page',
				'type'    => 'switch',
				'title'   => esc_html__( 'Show Sidebar', 'amarou' ),
				'default' => false,
				'indent'  => true
			),
			array(
				'id'           => 'sidebar_page_pos',
				'type'         => 'button_set',
				'title'        => esc_html__( 'Sidebar Position', 'amarou' ),
				'options'      => array(
					'left'  => esc_html__( 'Left', 'amarou' ),
					'right' => esc_html__( 'Right', 'amarou' ),
				),
				'default'      => 'right',
				'required'     => array( 0 => 'show_sidebar_page', 1 => '=', 2 => '1' ),
				'force_output' => true
			),
		)
	) );

	$metabox->add_section( 'page', array(
		'title'  => esc_html__( 'Footer', 'amarou' ),
		'desc'   => esc_html__( 'Settings for footer area.', 'amarou' ),
		'icon'   => 'el el-website',
		'fields' => array(
			array(
				'id'      => 'custom_footer',
				'type'    => 'switch',
				'title'   => esc_html__( 'Custom Layout', 'amarou' ),
				'default' => false,
				'indent'  => true
			),
	        array(
	            'id'          => 'footer_layout_custom',
	            'type'        => 'select',
	            'title'       => esc_html__('Layout', 'amarou'),
	            'desc'        => sprintf(esc_html__('To use this Option please %sClick Here%s to add your custom footer layout first.','amarou'),'<a href="' . esc_url( admin_url( 'edit.php?post_type=footer' ) ) . '">','</a>'),
	            'options'     => amarou_list_post('footer'),
	            'default'     => '',
	            'required' => array( 0 => 'custom_footer', 1 => 'equals', 2 => '1' ),
	            'force_output' => true
	        ),
	    )
	) );


	/**
	 * Config case study meta options
	 *
	 */
	$metabox->add_section( 'portfolio', array(
		'title'  => esc_html__( 'General', 'amarou' ),
		'icon'   => 'el-icon-website',
		'fields' => array(
			array(
				'id'       => 'portfolio_except',
				'type'     => 'textarea',
				'title'    => esc_html__( 'Except', 'amarou' ),
				'validate' => 'no_html'
			),
			array(
				'id'             => 'portfolio_content_padding',
				'type'           => 'spacing',
				'output'         => array( '.single-portfolio #content' ),
				'right'          => false,
				'left'           => false,
				'mode'           => 'padding',
				'units'          => array( 'px' ),
				'units_extended' => 'false',
				'title'          => esc_html__( 'Content Padding', 'amarou' ),
				'subtitle'     => esc_html__( 'Content site paddings.', 'amarou' ),
				'desc'           => esc_html__( 'Default: Theme Option.', 'amarou' ),
				'default'        => array(
					'padding-top'    => '',
					'padding-bottom' => '',
					'units'          => 'px',
				)
			),
		)
	) );

	$metabox->add_section( 'portfolio', array(
		'title'  => esc_html__( 'Page Title', 'amarou' ),
		'icon'   => 'el el-indent-left',
		'fields' => array(
			array(
				'id'           => 'custom_pagetitle',
				'type'         => 'button_set',
				'title'        => esc_html__( 'Page Title', 'amarou' ),
				'options'      => array(
					'themeoption'  => esc_html__( 'Theme Option', 'amarou' ),
					'show'  => esc_html__( 'Custom', 'amarou' ),
					'hide'  => esc_html__( 'Hide', 'amarou' ),
				),
				'default'      => 'themeoption',
			),
		)
	) );

	/**
	 * Config service meta options
	 *
	 */
	$metabox->add_section( 'service', array(
		'title'  => esc_html__( 'General', 'amarou' ),
		'icon'   => 'el-icon-website',
		'fields' => array(
			array(
				'id'           => 'icon_type',
				'type'         => 'button_set',
				'title'        => esc_html__( 'Icon Type', 'amarou' ),
				'options'      => array(
					's_icon'  => esc_html__( 'Icon', 'amarou' ),
					's_image'  => esc_html__( 'Image', 'amarou' ),
				),
				'default'      => 's_icon',
			),

			array(
	            'id'       => 'service_icon',
	            'type'     => 'cms_iconpicker',
	            'title'    => esc_html__('Icon', 'amarou'),
	            'default' => '',
	            'required'     => array( 0 => 'icon_type', 1 => 'equals', 2 => 's_icon' ),
				'force_output' => true
	        ),
	        array(
	            'id'       => 'service_icon_img',
	            'type'     => 'media',
	            'title'    => esc_html__('Icon Image', 'amarou'),
	            'required'     => array( 0 => 'icon_type', 1 => 'equals', 2 => 's_image' ),
				'force_output' => true
	        ),


			array(
				'id'       => 'service_except',
				'type'     => 'textarea',
				'title'    => esc_html__( 'Except', 'amarou' ),
				'validate' => 'no_html'
			),
			array(
                'id'       => 'service_feature',
                'type'     => 'multi_text',
                'title'    => esc_html__('Feature', 'amarou'),
                'validate' => 'html',
            ),
			array(
				'id'             => 'case_study_content_padding',
				'type'           => 'spacing',
				'output'         => array( '.single-service #content' ),
				'right'          => false,
				'left'           => false,
				'mode'           => 'padding',
				'units'          => array( 'px' ),
				'units_extended' => 'false',
				'title'          => esc_html__( 'Content Padding', 'amarou' ),
				'subtitle'     => esc_html__( 'Content site paddings.', 'amarou' ),
				'desc'           => esc_html__( 'Default: Theme Option.', 'amarou' ),
				'default'        => array(
					'padding-top'    => '',
					'padding-bottom' => '',
					'units'          => 'px',
				)
			),
		)
	) );
	$metabox->add_section( 'service', array(
		'title'  => esc_html__( 'Header', 'amarou' ),
		'desc'   => esc_html__( 'Header settings for the page.', 'amarou' ),
		'icon'   => 'el-icon-website',
		'fields' => array(
			array(
				'id'      => 'custom_header',
				'type'    => 'switch',
				'title'   => esc_html__( 'Custom Header', 'amarou' ),
				'default' => false,
				'indent'  => true
			),
			array(
				'id'           => 'header_layout',
				'type'         => 'image_select',
				'title'        => esc_html__( 'Layout', 'amarou' ),
				'subtitle'     => esc_html__( 'Select a layout for header.', 'amarou' ),
				'options'      => array(
					'0' => get_template_directory_uri() . '/assets/images/header-layout/h0.jpg',
					'1' => get_template_directory_uri() . '/assets/images/header-layout/h1.jpg',
					'2' => get_template_directory_uri() . '/assets/images/header-layout/h2.jpg',
				),
				'default'      => amarou_get_option_of_theme_options( 'header_layout' ),
				'required'     => array( 0 => 'custom_header', 1 => 'equals', 2 => '1' ),
				'force_output' => true
			),
		)
	) );
	$metabox->add_section( 'service', array(
		'title'  => esc_html__( 'Page Title', 'amarou' ),
		'icon'   => 'el el-indent-left',
		'fields' => array(
			array(
				'id'           => 'custom_pagetitle',
				'type'         => 'button_set',
				'title'        => esc_html__( 'Page Title', 'amarou' ),
				'options'      => array(
					'themeoption'  => esc_html__( 'Theme Option', 'amarou' ),
					'show'  => esc_html__( 'Custom', 'amarou' ),
					'hide'  => esc_html__( 'Hide', 'amarou' ),
				),
				'default'      => 'themeoption',
			),
		)
	) );

}

function amarou_get_option_of_theme_options( $key, $default = '' ) {
	if ( empty( $key ) ) {
		return '';
	}
	$options = get_option( amarou_get_opt_name(), array() );
	$value   = isset( $options[ $key ] ) ? $options[ $key ] : $default;

	return $value;
}